pub enum TxPoolWriteError {
DoubleSpend(TransactionHash),
TxPool(TxPoolError),
}Expand description
An error that can occur on some tx-write ops.
Variants
DoubleSpend(TransactionHash)
The transaction could not be added as it double spends another tx in the pool.
The inner value is the hash of the transaction that was double spent.
TxPool(TxPoolError)