in_stem_pool

Function in_stem_pool 

pub fn in_stem_pool(
    tx_hash: &TransactionHash,
    snapshot: &Snapshot,
    db: &TxpoolDatabase,
) -> Result<bool, TxPoolError>
Returns true if the transaction with the given hash is in the stem pool.

Errors

This will return an Err if the transaction is not in the pool.